# Road Map v0.9.5

!!!tip inline end "Need Help?"
    The SuperCowPowers team is happy to give any assistance needed when setting up AWS and Workbench. So please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 

The Workbench framework continues to flex to support different real world use cases when operating a set of production machine learning pipelines.


## General
**ML Pipelines**

We've learned a lot from our beta testers!

One of the important lessons is that when you make it easier to build ML Pipelines the users are going to build lots of pipelines.

For the creation, monitoring, and deployment of 50-100 of pipelines, we need to focus on the consoldation of artifacts into `Pipelines`. 

**Pipelines are DAGs**

The use of Directed Acyclic Graphs for the storage and management of ML Pipelines will provide a good abstraction. Real world ML Pipelines will often branch multiple times, 1 DataSource may become 2 FeatureSets might become 3 Models/Endpoints. 



**New Pipeline Dashboard Top Page**

The current main page shows all the individual artifacts, as we scale up to 100's models we need 2 additional levels of aggregation:

- Pipeline Groups
    - Group_1
        - Pipeline_1 (DS, FS, Model, Endpoint)
        - Pipeline_2 (DS, FS, Model, Endpoint)
    - Group_2
        - Pipeline_3 (DS, FS...)
        - Pipeline_4 (DS, FS...)
   

**New Pipeline Details Page**

When a pipeline is clicked on the top page, a Pipeline details page comes up for that specific pipeline. This page will give all relevant information about the pipeline, including model performance, monitoring, and endpoint status.


Awesome image TBD

## Versioned Artifacts
Our beta customers have requested versioning for artifacts, so we support versioning for both Model and FeatureSets. Endpoints and DataSources typically do not need versioning, so we may wait on the versioning support for those artifact until a later version.

## Questions?
<img align="right" src="../../images/scp.png" width="180">

The SuperCowPowers team is happy to answer any questions you may have about AWS and Workbench. Please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 


